import click

_global_test_options = [
    click.option('--debug/--no-debug', default=False, help='Debug mode'),
    click.option('--quiet/--no-quiet', default=False, help='Silent mode'),
]


def global_options(func):
    for option in reversed(_global_test_options):
        func = option(func)
    return func



import click

from chaosloader.src.utils.decorators.common import global_options
from chaosloader.src.commands.validate import command as validate_commands


@click.group()
@global_options
def cli(debug, quiet):
    """Welcome to chaos loader cli"""
    pass


@click.command()
@click.pass_context
def run(context):
    """RUN ALL"""


"""
Add available commands here
"""
cli.add_command(validate_commands.validate, name="validate")
cli.add_command(run, name="run")



import click

from chaosloader.src.utils.decorators.common import global_options


@click.command()
@click.pass_context
@global_options
def environment(context, debug, quiet):
    """Validate generated .env files"""
    click.echo("command apply works!")



from click.testing import CliRunner
from chaosloader.src.cli import cli


class TestClass(object):

    def test_environment(self):
        runner = CliRunner()
        result = runner.invoke(cli, ['validate', 'environment'])
        assert result.exit_code == 0
        assert 'command apply works!' in result.output



from setuptools import find_packages
from distutils.core import setup
from chaosloader.test.pytest import PyTest


dependencies = [
    'click==7.0',
    'configparser==3.7.3',
]

dev_dependencies = [
    'behave==1.2.6',
    'pytest==3.5.0',
    'semver==2.7.9',
    'flake8==3.7.7',
    'pytest-runner',
    'pytest'
]

setup(
    name='chaosloader',
    version_config={
        "version_format": "{tag}",
        "starting_version": "1.0.0"
    },
    description='Chaos loader command line',
    author='Alberto Iglesias Gallego',
    url='https://github.com/albertoig/chaos-loader',
    packages=find_packages(exclude=['*tests']),
    include_package_data=True,
    install_requires=dependencies,
    python_requires='>3.5.2',
    extras_require={
        'dev': dev_dependencies
    },
    setup_requires=[
        'pytest-runner', 'better-setuptools-git-version'
    ],
    tests_require=dev_dependencies,
    test_suite='test.unittest',
    entry_points='''
        [console_scripts]
        chaosloader=chaosloader.src.cli:cli
    ''',
    py_modules=['chaosloader'],
    cmdclass={'test': PyTest},
)



import click

from chaosloader.src.utils.decorators.common import global_options
from chaosloader.src.commands.validate.environment.environment import environment
from chaosloader.src.commands.validate.environment.config import config


@click.group()
@click.pass_context
@global_options
def validate(context, debug, quiet):
    """Validate set of sub commands"""
    pass


validate.add_command(environment, name="environment")
validate.add_command(config, name="config")
